[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

# inventree-gridlabel-plugin

A label printing plugin for [InvenTree](https://inventree.org), which provides support for printing out labels in a grid layout.

## Installation

Install this plugin manually as follows:

```
pip install inventree-gridlabel-plugin
```

Or, add to your `plugins.txt` file to install automatically using the `invoke install` command:

```
inventree-label-plugin
```

## Configuration Options

**TODO**
